==> selenium-remote-driver-2.46.0-sources.jar: org/openqa/selenium/remote/RemoteActionChainExecutor.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.remote;

import com.google.common.collect.Maps;

import org.openqa.selenium.interactions.Action;
import org.openqa.selenium.interactions.ActionChainExecutor;
import org.openqa.selenium.interactions.CompositeAction;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * Executes advanced interactions API commands over wire
 */
public class RemoteActionChainExecutor implements ActionChainExecutor {
  protected final ExecuteMethod executor;

  public RemoteActionChainExecutor(ExecuteMethod executor) {
    this.executor = executor;
  }

  public void execute(Action action) {
    List<Action> actions = new ArrayList<Action>();
    if (action instanceof CompositeAction) {
      actions = ((CompositeAction) action).asList();
    } else {
      actions.add(action);
    }
    Map<String, Object> params = Maps.newHashMap();
    params.put("chain", actions);
    executor.execute(DriverCommand.ACTION_CHAIN, params);
  }
}

==> selenium-remote-driver-2.52.0-sources.jar: org/openqa/selenium/remote/RemoteActionChainExecutor.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.remote;

import com.google.common.collect.Maps;

import org.openqa.selenium.interactions.Action;
import org.openqa.selenium.interactions.ActionChainExecutor;
import org.openqa.selenium.interactions.CompositeAction;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * Executes advanced interactions API commands over wire
 */
public class RemoteActionChainExecutor implements ActionChainExecutor {
  protected final ExecuteMethod executor;

  public RemoteActionChainExecutor(ExecuteMethod executor) {
    this.executor = executor;
  }

  public void execute(Action action) {
    List<Action> actions = new ArrayList<>();
    if (action instanceof CompositeAction) {
      actions = ((CompositeAction) action).asList();
    } else {
      actions.add(action);
    }
    Map<String, Object> params = Maps.newHashMap();
    params.put("chain", actions);
    executor.execute(DriverCommand.ACTION_CHAIN, params);
  }
}
